function C = ChR2activation_behavior(lightFile, behaviorFile, behavior)
%C = ChR2activation_behavior(lightFile, behaviorFile, {'Attack', 'Chase'})
%lightFile: the annotation file for light and sham stimulation
%behaviorFile: annotation file for behavior
%the purpose of this function is to compare behavior during light and sham stimulation

%%load annotated data
A = behaviorData('load', lightFile);
B = behaviorData('load', behaviorFile);

%STIMULATION
stimID = A.getIds(strfind_part(A.getNames(), {'light'}));
stimon = A.getStart(stimID);
stimoff = A.getEnd(stimID);

C.stimon= stimon/25;
C.stimoff = stimoff/25;
C.stimdur = (stimoff-stimon)/25;

shamID = A.getIds(strfind_part(A.getNames(), {'sham'}));
shamon = A.getStart(shamID);
shamoff = A.getEnd(shamID);

C.shamon= shamon/25;
C.shamoff = shamoff/25;
C.shamdur = (shamoff-shamon)/25;

a = 1:length(B.getNames()); a=a';
behaviorID =[]; 
for m=1:length(behavior)
    behaviorID = [behaviorID, B.getIds(a(strcmpi(B.getNames(), behavior{m})))];
end
behaviorID = sort(behaviorID, 'ascend');
behavioron = B.getStart(behaviorID);
behavioroff = B.getEnd(behaviorID);
% behaviorbreak = behavioron(2:end)-behavioroff(1:end-1); 
% behavioron= behavioron([1, find(behaviorbreak>5)+1]); 
% behavioroff =[behavioroff(behaviorbreak>5), behavioroff(end)];
% behaviordur = (behavioroff-behavioron)/25;
behaviorall=[];
for i =1:length(behavioron)
    behaviorall = [behaviorall, behavioron(i):behavioroff(i)];
end

C.behavioron= behavioron/25;
C.behavioroff = behavioroff/25;
C.behaviorall = behaviorall;

stop_behavior_latency=nan(1, length(stimID));
stop_behavior_latency_sham=nan(1, length(shamID));
restart_behavior_latency =nan(1, length(stimID));
restart_behavior_latency_sham = nan(1,length(shamID));
afterstim_behavior_latency = nan(1, length(stimID));
aftersham_behavior_latency = nan(1, length(shamID));

%real stimulation behavior duration
for i=1:length(stimID)
    C.stimbehavior_on(i)=length(intersect(behaviorall, stimon(i):stimoff(i)))/25;
end

%SHAM stimulation behavior duration
for i=1:length(shamID)
    C.shambehavior_on(i)=length(intersect(behaviorall, shamon(i):shamoff(i)))/25;
end


for i = 1:length(stimID)
    %stop behavior latency
    if ismember(stimon(i)-1, behaviorall)
        ID = find(behavioroff >= stimon(i));
        stop_behavior_latency(i) = behavioroff(ID(1))-stimon(i);
    else
        stop_behavior_latency(i) = nan;
    end
    %start behavior latency
    if ~isempty(intersect(behavioron, stimon(i):stimoff(i)))
        ID = find(behavioron>= stimon(i) & behavioron<= stimoff(i));
        restart_behavior_latency(i) = behavioron(ID(1))-stimon(i);
    else
        restart_behavior_latency(i) = nan;
    end
end
C.stop_behavior_latency = stop_behavior_latency/25;
C.restart_behavior_latency = restart_behavior_latency/25;

for i = 1:length(shamID)
    %stop behavior latency
    if ismember(shamon(i)-1, behaviorall)
        ID = find(behavioroff >= shamon(i));
        stop_behavior_latency_sham(i) = behavioroff(ID(1))-shamon(i);
    else
        stop_behavior_latency_sham(i) = nan;
    end
    %start behavior latency
    if ~isempty(intersect(behavioron, shamon(i):shamoff(i)))
        ID = find(behavioron>= shamon(i) & behavioron<= shamoff(i));
        restart_behavior_latency_sham(i) = behavioron(ID(1))-shamon(i);
    else
        restart_behavior_latency_sham(i) = nan;
    end
end
C.stop_behavior_latency_sham = stop_behavior_latency_sham/25;
C.restart_behavior_latency_sham = restart_behavior_latency_sham/25;

[~,C.stop_behavior_latency_p] = ttest2(C.stop_behavior_latency, C.stop_behavior_latency_sham);
[~,C.restart_behavior_latency_p] = ttest2(C.restart_behavior_latency, C.restart_behavior_latency_sham);
[~, C.behavior_pent_p] = ttest2(C.stimbehavior_on./C.stimdur*100,C.shambehavior_on./C.shamdur*100);

